@@ -201,6 +201,8 @@ class FhirToAttributeDict:
     def get_address(addresses: Optional[List[AddressType]]) -> Optional[AddressType]:
         if not addresses or len(addresses) == 0:
             return None
+
+        # 1. use == "official"
         official_addresses = [
             address for address in addresses if address.use == "official"
         ]
@@ -209,8 +211,15 @@ class FhirToAttributeDict:
         )
         if official_address:
             return official_address
+
+        # 2. use == "home"
         home_addresses = [address for address in addresses if address.use == "home"]
-        return home_addresses[0] if len(home_addresses) > 0 else None
+        home_address = home_addresses[0] if len(home_addresses) > 0 else None
+        if home_address:
+            return home_address
+
+        # 3. IF there is no use property, use the first address element by default
+        return addresses[0]
 
     @staticmethod
     def calculate_age_in_years(birthdate: Optional[date]) -> Optional[int]:
